import React from 'react';
import { Icon, Button, Input, Select, Spin, Table, Switch, message, DatePicker, Modal } from 'antd';
import ajax from 'jquery/src/ajax/xhr.js';
import $ from 'jquery/src/ajax';
import moment from 'moment';
import './techAchievement.less';
import TechDemandDesc from './achievementDesc.jsx';
import { achievementType,achievementCategoryList } from '@/dataDic.js';
import { IndustryObject, getIndustryCategory } from '@/DicIndustryList.js';
import { getTransaction,getReleaseStateList ,getAchievementCategory,getAchievementType} from '@/tools.js';

const DemandList = React.createClass({
    loadData(pageNo) {
        this.state.data = [];
        this.setState({
            page:pageNo,
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/achievement/list",
            data: {
                pageNo: pageNo || 1,
                pageSize: this.state.pagination.pageSize,
                ownerName: this.state.employerNameSearch,//客户名称
                name: this.state.nameSearch,
                dataCategory: this.state.dataCategorySearch ? Number(this.state.dataCategorySearch) : undefined,
                auditStatus:this.state.auditStatusSearch,
                startDate: this.state.releaseDate[0],
                endDate: this.state.releaseDate[1],
            },
            success: function (data) {
                let theArr = [];
                if (!data.data || !data.data.list) {
                    if (data.error && data.error.length) {
                        message.warning(data.error[0].message);
                    };
                } else {
                    for (let i = 0; i < data.data.list.length; i++) {
                        let thisdata = data.data.list[i];
                        theArr.push({
                            key: i,
                            id: thisdata.id,
                            serialNumber: thisdata.serialNumber,
                            name: thisdata.name,
                            category:thisdata.category,
                            fieldA:thisdata.thisdata,
                            fieldB:thisdata.fieldB,
                            dataCategory: thisdata.dataCategory,
                            auditStatus: thisdata.auditStatus,
                            isHot: thisdata.isHot,
                            boutique: thisdata.boutique,
                            ownerName:thisdata.ownerName,
                            releaseDate:thisdata.releaseDate?(new Date(thisdata.releaseDate)).toLocaleString():''
                        });
                    };
                }
                this.state.pagination.current = data.data.pageNo;
                this.state.pagination.total = data.data.totalCount;
                if(data.data&&data.data.list&&!data.data.list.length){
					this.state.pagination.current=0
					this.state.pagination.total=0
				}
                this.setState({
                    dataSource: theArr,
                    pagination: this.state.pagination
                });
            }.bind(this),
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    getInitialState() {
        return {
            searchMore: true,
            validityPeriodDate: [],
            releaseDate: [],
            selectedRowKeys: [],
            selectedRows: [],
            loading: false,
            pagination: {
                defaultCurrent: 1,
                defaultPageSize: 10,
                showQuickJumper: true,
                pageSize: 10,
                onChange: function (page) {
                    this.loadData(page);
                }.bind(this),
                showTotal: function (total) {
                    return '共' + total + '条数据';
                }
            },
            columns: [
                {
                    title: '编号',
                    dataIndex: 'serialNumber',
                    key: 'serialNumber',
                }, {
                    title: '成果名称',
                    dataIndex: 'name',
                    key: 'name',
                },  {
                    title: '成果类型',
                    dataIndex: 'dataCategory',
                    key: 'dataCategory',
                    render: (text) => { return getAchievementType(text); }
                },
                {
                    title: '知识产权类型',
                    dataIndex: 'category',
                    key: 'category',
                    render: (text) => { return getAchievementCategory(text); }
                },
                {
                    title: '精品标识',
                    dataIndex: 'boutique',
                    key: 'boutique',
                    render: text => { return text?'精品':'非精品' }
                },
                {
                    title: '客户名称',
                    dataIndex: 'ownerName',
                    key: 'ownerName'
                },
                {
                    title: '发布状态',
                    dataIndex: 'auditStatus',
                    key: 'auditStatus',
                    render: text => { return getReleaseStateList(text) }
                },
                {
                    title: '发布时间',
                    dataIndex: 'releaseDate',
                    key: 'releaseDate'
                }
            ],
            dataSource: [],
            searchTime: [,]
        };
    },
    componentWillMount() {
        let theArr = [];
        achievementType.map(function (item) {
            theArr.push(
                <Select.Option value={item.value} key={item.key}>{item.key}</Select.Option>
            )
        });
        this.state.demandTypeOption = theArr;
        this.loadData();
    },
    tableRowClick(record, index) {
        this.state.RowData = record;
        this.setState({
            showDesc: true,
            examineState:false
        });
    },
    delectRow(recard) {
        this.setState({
            loading:true
        })
        let deletedIds =[];
        let rowItem = this.state.selectedRowKeys[0];
        let data = this.state.dataSource ||[];
        if (data.length) {
            deletedIds.push(data[rowItem].id);
        }
        $.ajax({
            method: "POST",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/achievement/annul",
            data: {
                id: deletedIds[0]
            }
        }).done(function (data) {
            if (!data.error.length) {
                message.success('下架成功！');
                this.setState({
                    loading: false,
                    selectedRowKeys:[],
                });
            } else {
                message.warning(data.error[0].message);
            };
            this.loadData();
        }.bind(this));
    },
    closeDesc(e, s) {
        this.state.showDesc = e;
        if (s) {
            this.loadData(this.state.page);
        };
    },
    search() {
        this.loadData();
    },
    reset() {
        this.state.nameSearch = '';
        this.state.dataCategorySearch = undefined;
        this.state.auditStatusSearch = undefined;
        this.state.releaseDate = [];
        this.state.employerNameSearch=''
        this.loadData();
    },
    searchSwitch() {
        this.setState({
            searchMore: !this.state.searchMore
        });
    },
    render() {
        const rowSelection = {
            selectedRowKeys: this.state.selectedRowKeys,
            onChange: (selectedRowKeys, selectedRows) => {
                this.setState({
                    selectedRows: selectedRows.slice(-1),
                    selectedRowKeys: selectedRowKeys.slice(-1)
                });
            }
        };
        const hasSelected = this.state.selectedRowKeys.length > 0;
        const { RangePicker } = DatePicker;
        const hasSelect = this.state.selectedRowKeys.length;
        return (
            <div className="user-content" >
                <div className="content-title">
                    <span>科技成果库</span>
                </div>
                <div className="user-search">
                    <Input placeholder="成果名称"
                        value={this.state.nameSearch}
                        onChange={(e) => { this.setState({ nameSearch: e.target.value }); }} />
                    <Select placeholder="发布状态" style={{ width: 120 }}
                        value={this.state.auditStatusSearch}
                        onChange={(e) => { this.setState({ auditStatusSearch: e }) }}>
                        <Select.Option value="0" >草稿</Select.Option>
                        <Select.Option value="1" >发布审核</Select.Option>
                        <Select.Option value="2" >已发布</Select.Option>
                        <Select.Option value="3" >发布失败</Select.Option>
                        <Select.Option value="4" >已撤销</Select.Option>
                    </Select>
                    <Select placeholder="成果类型" style={{ width: 120 }}
                        value={this.state.dataCategorySearch}
                        onChange={(e) => { this.setState({ dataCategorySearch: e }) }}>
                        { 
                            achievementType.map(function (item) {
                                return	<Select.Option value={item.value} key={item.key}>{item.key}</Select.Option>
                            })
                        }
                    </Select>
                    <Button type="primary" onClick={this.search}>搜索</Button>
                    <Button onClick={this.reset}>重置</Button>
                    <Button type="danger" disabled={!hasSelect}  onClick={(e)=>{this.delectRow()}}>下架</Button>
                    <span>更多搜索<Switch defaultChecked={false} onChange={this.searchSwitch} /></span>
                    <div className="search-more" style={this.state.searchMore ? { display: 'none' } : {}}>
                        <Input style={{width:140,marginRight:10}} value={this.state.employerNameSearch} onChange={(e)=>{this.setState({employerNameSearch:e.target.value})}} placeholder="客户名称"/>
                        <span>发布时间 :</span>
                        <RangePicker
                            value={[this.state.releaseDate[0] ? moment(this.state.releaseDate[0]) : null,
                            this.state.releaseDate[1] ? moment(this.state.releaseDate[1]) : null]}
                            onChange={(data, dataString) => { this.setState({ releaseDate: dataString }); }} />
                    </div>
                </div>
                <div className="patent-table">
                    <Spin spinning={this.state.loading}>
                        <Table columns={this.state.columns}
                            dataSource={this.state.dataSource}
                            rowSelection={rowSelection}
                            pagination={this.state.pagination}
                            onRowClick={this.tableRowClick} />
                    </Spin>
                </div>
                <TechDemandDesc
                    data={this.state.RowData}
                    examineState={this.state.examineState}
                    demandTypeOption={this.state.demandTypeOption}
                    showDesc={this.state.showDesc}
                    closeDesc={this.closeDesc} />
            </div>
        );
    }
});

export default DemandList;