import React from 'react';
import { Icon, Button, Input, Select, Spin, Table, Switch, message, DatePicker } from 'antd';
import $ from 'jquery/src/ajax';
import moment from 'moment';
import '@/account/demand/techDemand.less';
import NewDesc from '@/administration/product/proDesc';
import '@/administration/news/news.less';
import {proStatus,productType } from '@/dataDic.js';
import {getProStatus,getProductType } from '@/tools.js';

const DemandList = React.createClass({
    loadData(pageNo) {
        this.state.data = [];
        this.setState({
            selectedRowKeys:[],
            page:pageNo,
            loading: true
        });
        $.ajax({
            method: "get",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/community/list",
            data: {
                pageNo: pageNo || 1,
                pageSize: this.state.pagination.pageSize,
                title: this.state.nameSearch, //需求名称
                startTime: this.state.releaseDate[0],
                endTime: this.state.releaseDate[1],
                status:this.state.auditStatusSearch,
                category:this.state.typeSearch
            },
            success: function (data) {
                let theArr = [];
                if (!data.data || !data.data.list) {
                    if (data.error && data.error.length) {
                        message.warning(data.error[0].message);
                    };
                } else {
                    for (let i = 0; i < data.data.list.length; i++) {
                        let thisdata = data.data.list[i];
                        theArr.push({
                            key: i,
                            id: thisdata.id,
                            title: thisdata.title,
                            category:thisdata.category,
                            status: thisdata.status,
                            releaseTime:thisdata.releaseTime?(new Date(thisdata.releaseTime)).toLocaleString():''
                        });
                    };
                };
                this.state.pagination.current = data.data.pageNo;
                this.state.pagination.total = data.data.totalCount;
                if(data.data&&data.data.list&&!data.data.list.length){
					this.state.pagination.current=0
					this.state.pagination.total=0
				};
                this.setState({
                    dataSource: theArr,
                    pagination: this.state.pagination
                });
            }.bind(this),
        }).always(function () {
            this.setState({
                loading: false
            });
        }.bind(this));
    },
    getInitialState() {
        return {
            searchMore: true,
            validityPeriodDate: [],
            releaseDate: [],
            selectedRowKeys: [],
            selectedRows: [],
            loading: false,
            pagination: {
                defaultCurrent: 1,
                defaultPageSize: 10,
                showQuickJumper: true,
                pageSize: 10,
                onChange: function (page) {
                    this.loadData(page);
                }.bind(this),
                showTotal: function (total) {
                    return '共' + total + '条数据';
                }
            },
            columns: [
                {
                    title: '专栏名称',
                    dataIndex: 'title',
                    key: 'title',
                    render:text=>{
                        return text&&text.length>30?text.substr(0,30)+'...':text
                    }
                }, 
                {
                    title: '产品类型',
                    dataIndex: 'category',
                    key: 'category',
                    render:text=>{return getProductType(text)}
                },
                {
                    title: '发布状态',
                    dataIndex: 'status',
                    key: 'status',
                    render: text => { return getProStatus(text) }
                },
                {
                    title: '发布时间',
                    dataIndex: 'releaseTime',
                    key: 'releaseTime'
                },
                {
                    title: '操作',
                    dataIndex: 'caozuo',
                    key: 'caozuo',
                    render:(text,recard) => {
                        return  <div className="btnRight">
                                   {recard.status!='1'&&<Button type="primary" style={{ background: "#3fcf9e", border: "none", color: "#fff" }} onClick={(e)=>{e.stopPropagation(),this.submission(recard,1)}}>发布</Button>}
                                   {recard.status=='1'&&<Button type="danger" onClick={(e)=>{e.stopPropagation(),this.submission(recard,3)}}>撤销发布</Button>}
                                </div>
                    }
                }
            ],
            dataSource: [],
            searchTime: [,]
        };
    },
    //发布
    submission(record,status){
        this.setState({
            showDesc:false,
            loading:true
        });
        $.ajax({
            method: "POST",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/community/updateCommunity",
            data: {
                id:record.id,
                status:status
            }
        }).done(function (data) {
            if (!data.error.length) {
                message.success('操作成功.');
                this.setState({
                    loading: false,
                });
                this.loadData(this.state.page)
            } else {
                message.warning(data.error[0].message);
            };
        }.bind(this));
    },
    componentWillMount() {
        this.loadData();
    },
    tableRowClick(record, index) {
        this.state.RowData = record;
        this.setState({
            showDesc: true
        });
    },
    delectRow(recard) {
        this.setState({
            loading:true
        })
        let deletedIds =[];
        let rowItem = this.state.selectedRowKeys[0];
        let data = this.state.dataSource ||[];
        if (data.length) {
            deletedIds.push(data[rowItem].id);
        }
        $.ajax({
            method: "POST",
            dataType: "json",
            crossDomain: false,
            url: globalConfig.context + "/api/admin/community/updateCommunity",
            data: {
                id: deletedIds[0],
                status:2
            }
        }).done(function (data) {
            if (!data.error.length) {
                message.success('删除成功！');
                this.setState({
                    loading: false
                });
                this.loadData(this.state.page);
            } else {
                message.warning(data.error[0].message);
            };
        }.bind(this));
    },
    addClick() {
        this.state.RowData = {};
        this.setState({
            showDesc: true
        });
    },
    closeDesc(e, s) {
        this.state.showDesc = e;
        if (s) {
            this.loadData(this.state.page);
        };
    },
    search() {
        this.loadData();
    },
    reset() {
        this.state.nameSearch = '';
        this.state.typeSearch=undefined;
        this.state.releaseDate = [];
        this.state.dataCategorySearch = undefined;
        this.state.auditStatusSearch = undefined;
        this.loadData();
    },
    searchSwitch() {
        this.setState({
            searchMore: !this.state.searchMore
        });
    },
    render() {
        const rowSelection = {
            selectedRowKeys: this.state.selectedRowKeys,
            onChange: (selectedRowKeys, selectedRows) => {
                this.setState({
                    selectedRows: selectedRows.slice(-1),
                    selectedRowKeys: selectedRowKeys.slice(-1)
                });
            }
        };
        const { RangePicker } = DatePicker;
        const hasSelect = this.state.selectedRowKeys.length;
        return (
            <div className="user-content" >
                <div className="content-title">
                    <span>产品专栏管理</span>
                    <div className="patent-addNew">
                        <Button type="primary" onClick={this.addClick}>发布<Icon type="plus" /></Button>
                    </div>
                </div>
                <div className="user-search">
                    <Input placeholder="专栏名称"
                        value={this.state.nameSearch}
                        onChange={(e) => { this.setState({ nameSearch: e.target.value }); }} />
                    <Select placeholder="发布状态" style={{ width: 120 }}
                        value={this.state.auditStatusSearch}
                        onChange={(e) => { this.setState({ auditStatusSearch: e }) }}>
                        {
                            proStatus.map(item=>{
                                return <Select.Option value={item.value}  >{item.key}</Select.Option>
                            })
                        }
                    </Select>
                    <Select placeholder="产品类型" style={{ width: 120 }}
                        value={this.state.typeSearch}
                        onChange={(e) => { this.setState({ typeSearch: e }) }}>
                         {
                            productType.map(item=>{
                                return <Select.Option value={item.value}  >{item.key}</Select.Option>
                            })
                        }
                    </Select>
                    <Button type="primary" onClick={this.search}>搜索</Button>
                    <Button onClick={this.reset}>重置</Button>
                    <Button type="danger" disabled={!hasSelect}  onClick={(e)=>{this.delectRow()}}>删除</Button>
                    <span>更多搜索<Switch defaultChecked={false} onChange={this.searchSwitch} /></span>
                    <div className="search-more" style={this.state.searchMore ? { display: 'none' } : {}}>
                        <span>发布时间 :</span>
                        <RangePicker
                            value={[this.state.releaseDate[0] ? moment(this.state.releaseDate[0]) : null,
                            this.state.releaseDate[1] ? moment(this.state.releaseDate[1]) : null]}
                            onChange={(data, dataString) => { this.setState({ releaseDate: dataString }); }} />
                    </div>
                </div>
                <div className="patent-table">
                    <Spin spinning={this.state.loading}>
                        <Table columns={this.state.columns}
                            dataSource={this.state.dataSource}
                            rowSelection={rowSelection}
                            pagination={this.state.pagination}
                            onRowClick={this.tableRowClick} />
                    </Spin>
                </div>
                <NewDesc
                    data={this.state.RowData}
                    showDesc={this.state.showDesc}
                    closeDesc={this.closeDesc} />
            </div >
        );
    }
});

export default DemandList;